@@ -1,4 +1,5 @@
-from typing import List
+from types import GeneratorType
+from typing import Any, Iterator, List
 
 from easydata import models
 from easydata.data import DataBag
@@ -9,6 +10,13 @@ from easydata.utils import mix
 
 __all__ = ("ModelManager",)
 
+MODEL_VARIANTS_KEYS = [
+    "variants_query",
+    "variants_source",
+    "variants_key_parser",
+    "variants_key_query",
+]
+
 
 class ModelManager(ConfigMixin):
     _ignore_item_attr_prefix = ["item_processors"]
@@ -18,6 +26,10 @@ class ModelManager(ConfigMixin):
 
         self._models: list = []
 
+        self._data_iter_query_processor = None
+
+        self._data_variants_processor = None
+
         self._item_parsers: dict = {}
 
         self._item_protected_names: List[str] = []
@@ -25,6 +37,7 @@ class ModelManager(ConfigMixin):
         self._config_properties: dict = {}
 
         self._data_processors_loader = ObjectLoader()
+
         self._item_processors_loader = ObjectLoader()
 
         self._init_model(model)
@@ -33,18 +46,6 @@ class ModelManager(ConfigMixin):
 
         self._init_parsers_config()
 
-    @property
-    def data_variants_name(self):
-        return self.config["ED_DATA_VARIANTS_NAME"]
-
-    @property
-    def data_variants_key_name(self):
-        return self.config["ED_DATA_VARIANTS_KEY_NAME"]
-
-    @property
-    def data_variant_name(self):
-        return self.config["ED_DATA_VARIANT_NAME"]
-
     @property
     def data_processors(self) -> ObjectLoader:
         return self._data_processors_loader
@@ -65,12 +66,15 @@ class ModelManager(ConfigMixin):
     def process_item_parser(self, item_key: str, data: DataBag):
         item_parser = self._item_parsers[item_key]
 
+        if not item_parser:
+            return None
+
         if isinstance(item_parser, (str, float, int, list, dict)):
             return item_parser
         elif isinstance(item_parser, models.ItemModel):
             data = data.copy(item_parser.model_manager)
 
-            return item_parser.parse(data)
+            return item_parser.parse_item(data)
         elif isinstance(item_parser, BaseParser):
             return item_parser.parse(data)
 
@@ -80,44 +84,81 @@ class ModelManager(ConfigMixin):
         self,
         data=None,
         **kwargs,
-    ):
+    ) -> Iterator[dict]:
 
         if not isinstance(data, DataBag):
             if data:
-                kwargs["data"] = data
+                kwargs["main"] = data
 
-            data = DataBag(self, **kwargs)
+            data = DataBag(**kwargs)
 
-        data = self._apply_data_processors(data)
+        if not data.has_model_manger_instance():
+            data.init_model_manager(self)
 
-        if data.has(self.data_variants_name):
-            for variant_data in self._parse_variants_data(data):
-                item = variant_data.get_all()
+        drop_item_exceptions = []
 
-                item = self._apply_item_processors(item)
+        for iter_data in self._apply_data_processors(data):
+            try:
+                yield self._data_to_item(iter_data)
+            except self._drop_item_exception as drop_item_exception:
+                # we store drop item exceptions so that other variations could
+                # get processed and we throw stored exceptions after iteration
+                # has ended
+                drop_item_exceptions.append(drop_item_exception)
 
-                yield self._remove_protected_item_keys(item)
+        if drop_item_exceptions:
+            if len(drop_item_exceptions) > 1:
+                raise self._drop_item_exception(drop_item_exceptions)
+
+            raise drop_item_exceptions[0]
+
+    @property
+    def _drop_item_exception(self):
+        return self.config["ED_DROP_ITEM_EXCEPTION"]
+
+    def _apply_data_processors(self, data: DataBag) -> Iterator[DataBag]:
+        data = self._process_models_preprocess_data(data)
+
+        data_processors = list(self._data_processors_loader.values())
+
+        if data_processors:
+            for iter_data in self._apply_processors(data, data_processors):
+                iter_data = self._process_models_process_data(iter_data)
+
+                yield iter_data
         else:
-            item = data.get_all()
-
-            item = self._apply_item_processors(item)
-
-            yield self._remove_protected_item_keys(item)
-
-    def _apply_data_processors(self, data: DataBag) -> DataBag:
-        for model in self._models:
-            data = model.preprocess_data(data)
-
-        data = mix.apply_processors(
-            value=data,
-            processors=list(self._data_processors_loader.values()),
-        )
+            yield data
 
+    def _process_models_process_data(self, data: DataBag):
         for model in self._models:
             data = model.process_data(data)
 
         return data
 
+    def _apply_processors(
+        self,
+        value: Any,
+        processors: list,
+    ) -> Any:
+
+        for processor in processors:
+            value = self._apply_processor(processor, value)
+
+        yield from value
+
+    def _apply_processor(self, processor, value):
+        if isinstance(value, GeneratorType):
+            for iter_value in value:
+                yield from processor.parse(iter_value)
+        else:
+            yield from processor.parse(value)
+
+    def _process_models_preprocess_data(self, data: DataBag):
+        for model in self._models:
+            data = model.preprocess_data(data)
+
+        return data
+
     def _apply_item_processors(self, item: dict) -> dict:
         for model in self._models:
             item = model.preprocess_item(item)
@@ -142,9 +183,16 @@ class ModelManager(ConfigMixin):
 
         return item
 
+    def _data_to_item(self, data: DataBag):
+        item = data.get_all()
+
+        item = self._apply_item_processors(item)
+
+        return self._remove_protected_item_keys(item)
+
     def _init_model(self, model):
-        if model.block_models:
-            for model_block in model.block_models:
+        if hasattr(model, "block_models"):
+            for model_block in getattr(model, "block_models"):
                 self._init_model(model_block)
 
         model.init_model()
@@ -153,11 +201,15 @@ class ModelManager(ConfigMixin):
 
         self._load_config_properties_from_model(model)
 
-        if model.data_processors:
-            self._data_processors_loader.add_list(model.data_processors)
+        if hasattr(model, "data_processors"):
+            data_processors = getattr(model, "data_processors")
 
-        if model.item_processors:
-            self._item_processors_loader.add_list(model.item_processors)
+            self._data_processors_loader.add_list(data_processors)
+
+        if hasattr(model, "item_processors"):
+            item_processors = getattr(model, "item_processors")
+
+            self._item_processors_loader.add_list(item_processors)
 
         model.initialized_model()
 
@@ -188,9 +240,9 @@ class ModelManager(ConfigMixin):
                 if item_name not in self._item_protected_names:
                     self._item_protected_names.append(item_name)
             else:
-                # If parser from parent model is not protected, then delete it from
-                # _item_protected_names list if exists, because child had protected
-                # parser with the same item name.
+                # If item parser from parent model is not protected, then
+                # delete it from _item_protected_names list if exists, because
+                # child had protected item parser with the same item name.
                 if item_name in self._item_protected_names:
                     self._item_protected_names.remove(item_name)
 
@@ -204,26 +256,3 @@ class ModelManager(ConfigMixin):
 
         for config_name, config_value in config_data:
             self._config_properties[config_name] = config_value
-
-    def _parse_variants_data(self, data):
-        variants_data = data[self.data_variants_name]
-
-        if isinstance(variants_data, dict):
-            for variant_key, variant_data in variants_data.items():
-                yield mix.make_variant_data_copy(
-                    data=data,
-                    variant_data=variant_data,
-                    variant_key=variant_key,
-                    variants_name=self.data_variants_name,
-                    variant_name=self.data_variant_name,
-                    variants_key_name=self.data_variants_key_name,
-                )
-        else:
-            for variant_data in variants_data:
-                yield mix.make_variant_data_copy(
-                    data=data,
-                    variant_data=variant_data,
-                    variants_name=self.data_variants_name,
-                    variant_name=self.data_variant_name,
-                    variants_key_name=self.data_variants_key_name,
-                )
