@@ -1,8 +1,11 @@
-from json import loads
-from typing import Any, Optional
+import json
+from typing import Any, Optional, Tuple
+
+import yaml
 
 from easydata.data import DataBag
 from easydata.queries.base import QuerySearch
+from easydata.utils import pseudo
 
 
 class KeyQuery(QuerySearch):
@@ -11,10 +14,14 @@ class KeyQuery(QuerySearch):
         query: str = None,
     ):
 
-        self._query = query
-        self._keys = False
-        self._values = False
-        self._dict_key_value = None
+        super().__init__(query)
+
+        self._keys: bool = False
+        self._values: bool = False
+        self._json: bool = False
+        self._yaml: bool = False
+        self._str: bool = False
+        self._dict_key_value: Optional[Tuple[str, str]] = None
 
         if self._query and "::" in self._query:
             self._initialize_custom_pseudo_keys()
@@ -22,10 +29,11 @@ class KeyQuery(QuerySearch):
     def _parse(
         self,
         data: Any,
+        query: Optional[str],
     ):
 
-        if self._query:
-            data = data.get(self._query)
+        if query:
+            data = data.get(query)
 
         return self._process_data_key_values(data)
 
@@ -48,7 +56,7 @@ class KeyQuery(QuerySearch):
                 return data[data_dict_source]
 
             try:
-                data_dict = loads(data[source])
+                data_dict = json.loads(data[source])
 
                 data[data_dict_source] = data_dict
 
@@ -56,12 +64,12 @@ class KeyQuery(QuerySearch):
             except Exception:
                 raise ValueError(
                     "Provided data from source {} could not be converted to dict or "
-                    "list in order to use key query!".format(source)
+                    "list in order to use query!".format(source)
                 )
         elif isinstance(data, (dict, list)):
             return data
 
-        return loads(data)
+        return json.loads(data)
 
     def _process_data_key_values(self, data):
         if data:
@@ -82,25 +90,63 @@ class KeyQuery(QuerySearch):
             if self._keys:
                 data = list(data.keys())
 
+            if self._json:
+                data = json.dumps(data)
+
+            if self._yaml:
+                data = yaml.dump(data)
+
+            if self._str and not isinstance(data, str):
+                data = str(data)
+
         return data
 
     def _initialize_custom_pseudo_keys(self):
-        query_parts = self._query.split("::")
+        self._query, pseudo_key = pseudo.get_key_from_query(self._query)
 
-        self._query = None if self._query.startswith("::") else query_parts[0]
+        pseudo_key = self._process_pseudo_key_extension(pseudo_key)
 
-        pseudo_key = query_parts[-1]
+        self._process_pseudo_key(pseudo_key)
 
+    def _process_pseudo_key_extension(self, pseudo_key: str) -> str:
+        pseudo_key, extension = pseudo.get_extension_value(pseudo_key, ["dict"])
+
+        if not extension:
+            return pseudo_key
+
+        if extension == "json":
+            self._json = True
+        elif extension == "yaml":
+            self._yaml = True
+        elif extension == "str":
+            self._str = True
+        else:
+            raise ValueError(
+                "Pseudo key extension {} is not supported. Currently supported "
+                "is only -json".format(extension)
+            )
+
+        return pseudo_key
+
+    def _process_pseudo_key(self, pseudo_key: str) -> None:
         if pseudo_key.startswith("dict"):
             dict_key_value_text = pseudo_key.split("(")[-1].split(")")[0]
-            dict_key_value_list = [v.strip() for v in dict_key_value_text.split(":")]
-            self._dict_key_value = tuple(dict_key_value_list)
+
+            dict_key_value_split = dict_key_value_text.split(":")
+
+            self._dict_key_value = dict_key_value_split[0], dict_key_value_split[1]
         elif pseudo_key == "values":
             self._values = True
         elif pseudo_key == "keys":
             self._keys = True
+        elif pseudo_key == "json":
+            self._json = True
+        elif pseudo_key == "yaml":
+            self._yaml = True
+        elif pseudo_key == "str":
+            self._str = True
         else:
             raise ValueError(
                 "Pseudo key '{}' is not supported. Currently supported are: keys,"
-                "values".format(pseudo_key)
+                "values, dict(<key>,<value>).".format(pseudo_key)
             )
