@@ -4,7 +4,6 @@ from easytxt.text import to_list
 from pyquery import PyQuery
 
 from easydata.config.loader import ConfigLoader
-from easydata.data import DataBag
 from easydata.parsers.base import Base
 from easydata.processors.base import BaseProcessor
 
@@ -129,26 +128,6 @@ def iter_attr_data_from_obj(
         yield attr_name, attr_value
 
 
-def make_variant_data_copy(
-    data: DataBag,
-    variant_data: Union[list, dict],
-    variant_key: Optional[str] = None,
-    variants_name: str = "variants",
-    variant_name: str = "variant",
-    variants_key_name: str = "variants_key",
-):
-
-    data_copy = data.copy()
-
-    data_copy[variants_name] = variant_data
-    data_copy[variant_name] = variant_data[0]
-
-    if variant_key:
-        data_copy[variants_key_name] = variant_key
-
-    return data_copy
-
-
 def multiply_list_values(
     list_values: list,
     split_key: Optional[str] = None,
